==> generator-0.0.54-sources.jar: cn/bestwu/generator/dsl/Generators.kt <==
package cn.bestwu.generator.dsl

import cn.bestwu.generator.GeneratorExtension
import cn.bestwu.generator.dsl.def.PlantUML
import cn.bestwu.generator.puml.PumlConverter

/**
 * 模板脚本
 * @author Peter Wu

 */
object Generators {
    lateinit var extension: GeneratorExtension
    val database = "database"
    val puml = "puml"

    /**
     * @param extension 配置
     */
    fun call(extension: GeneratorExtension) {
        if (extension.generators.isEmpty()) {
            return
        }
        when (extension.dataType) {
            database -> database(extension)
            puml -> puml(extension)
        }
    }

    fun database(extension: GeneratorExtension) {
        this.extension = extension
        val generators = extension.generators
        if (generators.isEmpty()) {
            return
        }
        generators.forEach { generator ->
            generator.setUp()
        }

        extension.use {
            if (extension.tableNames.isEmpty()) {
                extension.use {
                    extension.tableNames = tableNames().toTypedArray()
                }
            }
            extension.tableNames.forEach {
                val table = table(it)
                generators.forEach { generator ->
                    generator.call(table)
                }
            }
        }
        generators.forEach { generator ->
            generator.tearDown()
        }
    }

    fun puml(extension: GeneratorExtension) {
        this.extension = extension
        val generators = extension.generators
        if (generators.isEmpty()) {
            return
        }
        generators.forEach { generator ->
            generator.setUp()
        }

        val emptyTableNames = extension.tableNames.isEmpty()
        val allTableNames = mutableSetOf<String>()
        val findTableNames = mutableSetOf<String>()
        extension.pumlSources.forEach { file ->
            val tables = PumlConverter.toTables(file)
            if (emptyTableNames) {
                tables.forEach { table ->
                    allTableNames.add(table.tableName)
                    println("查询：${table.tableName} 表数据结构")
                    generators.forEach { generator ->
                        generator.module = file.nameWithoutExtension
                        generator.moduleName = PlantUML.umlName!!
                        generator.call(table)
                    }
                }
            } else {
                allTableNames.addAll(tables.map { it.tableName })
                extension.tableNames.forEach { tableName ->
                    println("查询：$tableName 表数据结构")
                    val table = tables.find { it.tableName == tableName }
                    if (table != null) {
                        findTableNames.add(tableName)
                        generators.forEach { generator ->
                            generator.module = file.nameWithoutExtension
                            generator.moduleName = PlantUML.umlName!!
                            generator.call(table)
                        }
                    }
                }
            }
        }

        if (!emptyTableNames) {
            val notFound = extension.tableNames.find { !findTableNames.contains(it) }
            if (notFound != null)
                throw RuntimeException("未在($allTableNames)中找到${notFound}表")
        }

        generators.forEach { generator ->
            generator.tearDown()
        }
    }

}

==> generator-0.0.55-sources.jar: cn/bestwu/generator/dsl/Generators.kt <==
package cn.bestwu.generator.dsl

import cn.bestwu.generator.GeneratorExtension
import cn.bestwu.generator.dom.java.JavaTypeResolver
import cn.bestwu.generator.dsl.def.PlantUML
import cn.bestwu.generator.puml.PumlConverter

/**
 * 模板脚本
 * @author Peter Wu

 */
object Generators {
    const val database = "database"
    const val puml = "puml"

    /**
     * @param extension 配置
     */
    fun call(extension: GeneratorExtension) {
        JavaTypeResolver.softDeleteColumnName = extension.softDeleteColumnName
        if (extension.generators.isEmpty()) {
            return
        }
        when (extension.dataType) {
            database -> database(extension)
            puml -> puml(extension)
        }
    }

    fun tableNames(extension: GeneratorExtension): List<String> {
        JavaTypeResolver.softDeleteColumnName = extension.softDeleteColumnName
        return when (extension.dataType) {
            Generators.database -> extension.use {
                tableNames()
            }
            Generators.puml -> {
                extension.pumlSources.map { PumlConverter.toTables(it) }.flatten().map { it.tableName }.toList()
            }
            else -> emptyList()
        }
    }

    fun database(extension: GeneratorExtension) {
        val generators = extension.generators
        if (generators.isEmpty()) {
            return
        }
        generators.forEach { generator ->
            generator.setUp(extension)
        }

        extension.use {
            if (extension.tableNames.isEmpty()) {
                extension.use {
                    extension.tableNames = tableNames().toTypedArray()
                }
            }
            extension.tableNames.forEach {
                val table = table(it)
                generators.forEach { generator ->
                    generator.call(extension, table)
                }
            }
        }
        generators.forEach { generator ->
            generator.tearDown(extension)
        }
    }

    fun puml(extension: GeneratorExtension) {
        val generators = extension.generators
        if (generators.isEmpty()) {
            return
        }
        generators.forEach { generator ->
            generator.setUp(extension)
        }

        val emptyTableNames = extension.tableNames.isEmpty()
        val allTableNames = mutableSetOf<String>()
        val findTableNames = mutableSetOf<String>()
        extension.pumlSources.forEach { file ->
            val tables = PumlConverter.toTables(file)
            if (emptyTableNames) {
                tables.forEach { table ->
                    allTableNames.add(table.tableName)
                    println("查询：${table.tableName} 表数据结构")
                    generators.forEach { generator ->
                        generator.module = file.nameWithoutExtension
                        generator.moduleName = PlantUML.umlName!!
                        generator.call(extension, table)
                    }
                }
            } else {
                allTableNames.addAll(tables.map { it.tableName })
                extension.tableNames.forEach { tableName ->
                    println("查询：$tableName 表数据结构")
                    val table = tables.find { it.tableName == tableName }
                    if (table != null) {
                        findTableNames.add(tableName)
                        generators.forEach { generator ->
                            generator.module = file.nameWithoutExtension
                            generator.moduleName = PlantUML.umlName!!
                            generator.call(extension, table)
                        }
                    }
                }
            }
        }

        if (!emptyTableNames) {
            val notFound = extension.tableNames.find { !findTableNames.contains(it) }
            if (notFound != null)
                throw RuntimeException("未在($allTableNames)中找到${notFound}表")
        }

        generators.forEach { generator ->
            generator.tearDown(extension)
        }
    }

}
